@@ -23,6 +23,7 @@ from .runners import (
     VSCodium,
     NotepadPP,
     Firefox,
+    SessionWorker,
     DefaultEditor,
     DefaultRunners,
 )
@@ -174,11 +175,24 @@ class SynchronizeFiles(Synchronize):
         return self.get_result(next_action=self.result.oid())
 
 
+class GotoBookmarks(flow.Action):
+    ICON = ("icons.gui", "star")
+
+    def needs_dialog(self):
+        return False
+    
+    def run(self, button):
+        return self.get_result(
+            goto=self.root().project().admin.bookmarks.oid()
+        )
+
+
 class Synchronization(flow.Object):
     ICON = ("icons.libreflow", "sync_arrow")
     
     _project = flow.Parent()
     synchronize_files = flow.Child(SynchronizeFiles)
+    bookmarks = flow.Child(GotoBookmarks)
 
     def summary(self):
         current_site = self._project.get_current_site()
@@ -412,6 +426,7 @@ class Project(KitsuProject):
         self._RUNNERS_FACTORY.ensure_runner_type(Explorer)
         self._RUNNERS_FACTORY.ensure_runner_type(MinioFileUploader)
         self._RUNNERS_FACTORY.ensure_runner_type(MinioFileDownloader)
+        self._RUNNERS_FACTORY.ensure_runner_type(SessionWorker)
         self._RUNNERS_FACTORY.ensure_runner_type(DefaultEditor)
 
     def ensure_runners_loaded(self):
