@@ -133,14 +133,31 @@ class Department(flow.Object):
     create_defaults = flow.Child(CreateDefaultFileSystemItemsAction).ui(
         label="Create default files"
     )
+    path = flow.Computed(cached=True)
 
     def get_default_contextual_edits(self, context_name):
         if context_name == "settings":
-            default_settings = get_contextual_dict(self._parent, context_name)
-            path = default_settings.get("path", "UNKNOWN_PATH")
-
             return dict(
-                path=os.path.join(path, self.name()),
                 department=self.name(),
                 context=self._parent.__class__.__name__.lower(),
             )
+    
+    def compute_child_value(self, child_value):
+        if child_value is self.path:
+            settings = get_contextual_dict(self, "settings")
+            file_category = settings["file_category"]
+            if file_category == "PROD":
+                path = os.path.join(
+                    file_category,
+                    settings["sequence"],
+                    settings["shot"],
+                    settings["department"],
+                )
+            elif file_category == "LIB":
+                path = os.path.join(
+                    file_category,
+                    settings["asset_name"],
+                    settings["department"],
+                )
+
+            child_value.set(path)
