@@ -163,10 +163,8 @@ class Revision(flow.Object):
         return os.path.join(self.path.get(), self.file_name.get())
     
     def get_relative_path(self):
-        file_path = get_contextual_dict(self._file, "settings")["path"]
-        
         return os.path.join(
-            file_path,
+            self._file.path.get(),
             self.name(),
             self.file_name.get()
         )
