@@ -67,10 +67,7 @@ class Asset(KitsuAsset):
 
     def get_default_contextual_edits(self, context_name):
         if context_name == "settings":
-            default_settings = get_contextual_dict(self._assets, context_name)
-            path = default_settings.get("path", "UNKNOWN_PATH")
-
-            return dict(path=os.path.join(path, self.name()), asset_name=self.name())
+            return dict(asset_name=self.name())
 
 
 class Assets(GenericItemMap):
@@ -98,7 +95,8 @@ class Assets(GenericItemMap):
 
     def get_default_contextual_edits(self, context_name):
         if context_name == "settings":
-            return dict(path="LIB", file_category="LIB")
+            # return dict(path="LIB", file_category="LIB")
+            return dict(file_category="LIB")
 
 
 class AssetFamily(flow.Object):
@@ -110,12 +108,7 @@ class AssetFamily(flow.Object):
 
     def get_default_contextual_edits(self, context_name):
         if context_name == "settings":
-            default_settings = get_contextual_dict(self._asset_type, context_name)
-            path = default_settings.get("path", "UNKNOWN_PATH")
-
-            return dict(
-                path=os.path.join(path, self.name()), asset_family=self.name().lower()
-            )
+            return dict(asset_family=self.name().lower())
 
 
 class AssetFamilies(flow.Map):
@@ -136,12 +129,7 @@ class AssetType(flow.Object):
 
     def get_default_contextual_edits(self, context_name):
         if context_name == "settings":
-            default_settings = get_contextual_dict(self._lib, context_name)
-            path = default_settings.get("path", "UNKNOWN_PATH")
-
-            return dict(
-                path=os.path.join(path, self.name()), asset_type=self.name().lower()
-            )
+            return dict(asset_tpye=self.name().lower())
 
 
 class AssetTypes(flow.Map):
@@ -159,7 +147,7 @@ class AssetLib(flow.Object):
 
     def get_default_contextual_edits(self, context_name):
         if context_name == "settings":
-            return dict(path="LIB", CATEGORY="LIB")
+            return dict(file_category="LIB")
 
 
 # Dependencies
