@@ -209,7 +209,9 @@ class SessionWorker(PythonRunner):
 
     def argv(self):
         args = [
-            "C:/Users/Baptiste/dev/LibreFlow/libreflow-git/src/libreflow/scripts/session_worker.py",
+            "%s/../scripts/session_worker.py" % (
+                os.path.dirname(__file__)
+            ),
             self.runner_name()
         ]
         args += self.extra_argv
