@@ -191,7 +191,9 @@ class ProcessJobs(flow.Action):
 class MinioFileUploader(PythonRunner):
     
     def argv(self):
-        args = ["C:/Users/Baptiste/dev/LibreFlow/libreflow-git/src/libreflow/scripts/minio_file_uploader.py"]
+        args = ["%s/../scripts/minio_file_uploader.py" % (
+            os.path.dirname(__file__)
+        )]
         args += self.extra_argv
         return args
 
@@ -199,7 +201,9 @@ class MinioFileUploader(PythonRunner):
 class MinioFileDownloader(PythonRunner):
     
     def argv(self):
-        args = ["C:/Users/Baptiste/dev/LibreFlow/libreflow-git/src/libreflow/scripts/minio_file_downloader.py"]
+        args = ["%s/../scripts/minio_file_downloader.py" % (
+            os.path.dirname(__file__)
+        )]
         args += self.extra_argv
         return args
 
