@@ -100,6 +100,7 @@ class AddEnvVarAction(flow.Action):
         json.dump(env, f, indent=4, sort_keys=True)
         f.close()
 
+        os.environ[self.var_name.get()] = self.var_value.get()
         self._env.touch()
 
 
@@ -132,17 +133,15 @@ class ChangeEnvVarValueAction(flow.Action):
         f.close()
 
         self._var.set(self.var_value.get())
+        self._var.update()
 
 
-class EnvVar(flow.values.Value):
+class EnvVar(flow.values.SessionValue):
 
     change_value = flow.Child(ChangeEnvVarValueAction)
 
-    def get(self):
-        value = super(EnvVar, self).get()
-        os.environ[self.name()] = value
-
-        return value
+    def update(self):
+        os.environ[self.name()] = self.get()
 
 
 class UserEnvironment(flow.DynamicMap):
@@ -177,7 +176,7 @@ class UserEnvironment(flow.DynamicMap):
 
     def update(self):
         for var in self.mapped_items():
-            var.get()
+            var.update()
 
     def columns(self):
         return ["Variable", "Value"]
