@@ -1,12 +1,12 @@
 from qtpy import QtCore
 
 from kabaret.app.ui import gui
+from kabaret.app.session import KabaretSession
 from kabaret.script_view import ScriptView
 from kabaret.subprocess_manager import SubprocessManager, LauncherToolBar
 
 
 class BaseGUISession(gui.KabaretStandaloneGUISession):
-
     def register_view_types(self):
         super(BaseGUISession, self).register_view_types()
 
@@ -18,9 +18,16 @@ class BaseGUISession(gui.KabaretStandaloneGUISession):
 
 
 class DebugGUISession(BaseGUISession):
-
     def register_view_types(self):
         super(DebugGUISession, self).register_view_types()
 
         type_name = self.register_view_type(ScriptView)
         self.add_view(type_name, hidden=True, area=QtCore.Qt.RightDockWidgetArea)
+
+
+class BaseCLISession(KabaretSession):
+    def _create_actors(self):
+        super(BaseCLISession, self)._create_actors()
+
+        # Configure SubprocessManager
+        SubprocessManager(self)
